**musicxml** is a python library for reading and writing musicxml files.

**musicxml** is also a part of library: **musicscore2**. Feel free to check out:

[https://github.com/alexgorji/musicxml](https://github.com/alexgorji/musicscore2)

[https://musicscore2.readthedocs.io](https://musicscore2.readthedocs.io)

INSTALLATION

.. include:: usage.rst

.. include:: intro_musicxml.rst

